local _, class = UnitClass("player")
if class == "HUNTER" then 
	local enable = true
else
	return 
end

local addon, L = MosphetCookies, MosphetCookies.L
assert(addon, "MosphetCookiesOptions requires MosphetCookies.")

local module = addon:NewModule("Options")
addon.Options = module

local AC = LibStub("AceConfig-3.0")
local ACD = LibStub("AceConfigDialog-3.0")
local SM = addon.media

-- -----------------
--  Locals
-- -----------------
local pairs, ipairs, tinsert = pairs, ipairs, tinsert
local format, strupper, strlower, strsub, strfind = string.format, string.upper, string.lower, string.sub, string.find
local rawget,unpack = rawget,unpack

local dbp
local unlocked
local options

function module:RegisterOptions()
	options = {
		name = "Mosphet Cookies",
		handler = addon,
		type = "group",
		args = {
			inline_enabled = {
				order = 1,
				type = "toggle",
				name = L["Enabled"],
				desc = L["Enable or disable addon"],
				descStyle = "inline",
				set = function(info,v)
					if addon:IsEnabled() then
						addon:Disable()
						dbp.enabled = false
					else
						addon:Enable()
						dbp.enabled = true
					end
				end,
				get = function() return addon:IsEnabled() end,
			},
			inline_lock = {
				order = 2,
				type = "toggle",
				name = L["Locked"],
				desc = L["Lock or unlock anchor"],
				descStyle = "inline",
				set = function(info,v) addon:ToggleAnchor(); unlocked = not unlocked end,
				get = function(info) return not unlocked end,
			},
			inline_versionheader = {
				name = ("Version: %d"):format(addon.version),
				type = "header",
				order = 3,
			},
			
		},
	}
	
	options.args.general = {
		name = "General",
		type = "group",
		order = 1,
		args = {
			resfresh = {
				order = 1,
				type = "range",
				name = L["Refresh Rate"],
				desc = L["Set the refresh rate in seconds to update the displays (Default: 1 second)"],
				min = 0.1,
				max = 3,
				step = 0.1,
				set = function(info,v) dbp.refresh = v; end,
				get = function() return dbp.refresh end,
			},
			Font = {
				order = 2,
				type = "select",
				name = L["Main Font"],
				desc = L["Font for the spell and cast display"],
				values = SM:HashTable("font"),
				dialogControl = "LSM30_Font",
				set = function(info,v) dbp.fontface = v; addon:UpdateFont() end,
				get = function() return dbp.fontface end,
			},
			fontsize = {
				order = 3,
				type = "range",
				name = L["Font Size"],
				desc = L["Select a font size (between 8 and 26)"],
				min = 8,
				max = 26,
				step = 1,
				set = function(info,v) dbp.fontsize = v; addon:UpdateFont() end,
				get = function() return dbp.fontsize end,
			},
			fontstyle = {
				order = 4,
				type = "select",
				name = L["Font Style"],
				desc = L["Select the font style"],
				values = {
					NONE = "None",
					OUTLINE = "Outline",
					THICKOUTLINE = "Thick Outline",
				},
				set = function(info,v) dbp.fontstyle = v; addon:UpdateFont() end,
				get = function() return dbp.fontstyle end,
			},
			justification = {
				order = 5,
				type = "select",
				name = L["Justification"],
				desc = L["Select the anchor justification"],
				values = {
					LEFT = "Left",
					CENTER = "Center",
					RIGHT = "Right",
				},
				set = function(info,v) dbp.justification = v; addon:UpdateJustification(v) end,
				get = function() return dbp.justification end,
			},				
		},
	}
	
	options.args.displays = {
		name = "Display Options",
		type = "group",
		order = 2,
		args = {
			desc1 = {
				name = L["Hunter Displays"],
				type = "header",
				order = 1,
			},
			aimed = {
				type = "toggle",
				name = L["Aimed Shot cast time"],
				order = 2,
				set = function(info,v) dbp.aimed = v end,
				get = function() return dbp.aimed end,
			},
			steady = {
				type = "toggle",
				name = L["Steady Shot cast time"],
				order = 3,
				set = function(info,v) dbp.steady = v end,
				get = function() return dbp.steady end,
			},
			cobra = {
				type = "toggle",
				name = L["Cobra Shot cast time"],
				order = 4,
				set = function(info,v) dbp.cobra = v end,
				get = function() return dbp.cobra end,
			},
			hastev = {
				type = "toggle",
				name = L["Current Haste Rating"],
				order = 5,
				set = function(info,v) dbp.hastev = v end,
				get = function() return dbp.hastev end,
			},
			hastep = {
				type = "toggle",
				name = L["Current Haste Percent"],
				order = 6,
				set = function(info,v) dbp.hastep = v end,
				get = function() return dbp.hastep end,
			},
			clear1 = {
				type = "description",
				name = "\n",
				order = 7,
				width = "full",
			},
			desc2 = {
				name = L["Pet Displays"],
				type = "header",
				order = 8,
			},
			petap = {
				type = "toggle",
				name = L["Pet Attack Power"],
				order = 9,
				set = function(info,v) dbp.petap = v end,
				get = function() return dbp.petap end,
			},
			rabid = {
				type = "toggle",
				name = L["Rabid Power Stack"],
				order = 10,
				set = function(info,v) dbp.rabid = v end,
				get = function() return dbp.rabid end,
			},
		},
	}
	
	options.args.colors = {
		name = L["Thresholds"],
		type = "group",
		order = 3,
		args = {
			desc = {
				type = "description",
				name = L["Use this section of the configuration to set threshold values & color behaviour for certain abilities."],
				order = 7,
				width = "full",
			},
			aimed = {
				name = L["Aimed Shot"],
				type = "group",
				order = 2,
				args = {
					aisdesc = {
						name = L["Aimed Shot"],
						type = "header",
						order = 1,
					},
					aisthreshenabled = {
						order = 2,
						type = "toggle",
						name = L["Enable"],
						desc = L["Enable Aimed Shot threshold"],
						set = function(info,v) dbp.aisthreshenabled = v end,
						get = function() return dbp.aisthreshenabled end,				
					},
					aisthresh = {
						order = 3,
						type = "range",
						name = format(L["Threshold (Default: %s)"], "1.8"),
						desc = L["Aimed Shot Threshold in seconds"],
						min = 0.1,
						max = 2.9,
						step = 0.1,
						set = function(info,v) dbp.aisthresh = v end,
						get = function() return dbp.aisthresh end,	
					},
					aisthreshgt = {
						order = 4,
						type = "color",
						name = L["Above threshold"],
						desc = L["Font color above the required Aimed Shot cast value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
					aisthreshlt = {
						order = 5,
						type = "color",
						name = L["Below threshold"],
						desc = L["Font color below the required Aimed Shot cast value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
				},
			},
			steady = {
				name = L["Steady Shot"],
				type = "group",
				order = 2,
				args = {
					ssdesc = {
						name = L["Steady Shot"],
						type = "header",
						order = 10,
					},
					ssthreshenabled = {
						order = 11,
						type = "toggle",
						name = L["Enable"],
						desc = L["Enable Steady Shot threshold"],
						set = function(info,v) dbp.ssthreshenabled = v end,
						get = function() return dbp.ssthreshenabled end,				
					},
					ssthresh = {
						order = 12,
						type = "range",
						name = format(L["Threshold (Default: %s)"], "1.0"),
						desc = L["Steady Shot Threshold in seconds"],
						min = 0.1,
						max = 2,
						step = 0.1,
						set = function(info,v) dbp.ssthresh = v end,
						get = function() return dbp.ssthresh end,	
					},
					ssthreshgt = {
						order = 13,
						type = "color",
						name = L["Above threshold"],
						desc = L["Font color above the required Steady Shot cast value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
					ssthreshlt = {
						order = 14,
						type = "color",
						name = L["Below threshold"],
						desc = L["Font color below the required Steady Shot cast value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
				},
			},
			cobra = {
				name = L["Cobra Shot"],
				type = "group",
				order = 3,
				args = {
					cosdesc = {
						name = L["Cobra Shot"],
						type = "header",
						order = 20,
					},
					costhreshenabled = {
						order = 21,
						type = "toggle",
						name = L["Enable"],
						desc = L["Enable Cobra Shot threshold"],
						set = function(info,v) dbp.costhreshenabled = v end,
						get = function() return dbp.costhreshenabled end,				
					},
					costhresh = {
						order = 22,
						type = "range",
						name = format(L["Threshold (Default: %s)"], "1.0"),
						desc = L["Cobra Shot Threshold in seconds"],
						min = 0.1,
						max = 2,
						step = 0.1,
						set = function(info,v) dbp.costhresh = v end,
						get = function() return dbp.costhresh end,	
					},
					costhreshgt = {
						order = 23,
						type = "color",
						name = L["Above threshold"],
						desc = L["Font color above the required Cobra Shot cast value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
					costhreshlt = {
						order = 24,
						type = "color",
						name = L["Below threshold"],
						desc = L["Font color below the required Cobra Shot cast value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
				},
			},
			rabid = {
				name = L["Rabid Power"],
				type = "group",
				order = 4,
				args = {
					rpdesc = {
						name = L["Rabid Power"],
						type = "header",
						order = 30,
					},
					rpthreshenabled = {
						order = 31,
						type = "toggle",
						name = L["Enable"],
						desc = L["Enable Rabid Power threshold"],
						set = function(info,v) dbp.rpthreshenabled = v end,
						get = function() return dbp.rpthreshenabled end,				
					},
					rpthresh = {
						order = 32,
						type = "range",
						name = format(L["Threshold (Default: %s)"], "5"),
						desc = L["Rabid Power stack Threshold"],
						min = 1,
						max = 5,
						step = 1,
						set = function(info,v) dbp.rpthresh = v end,
						get = function() return dbp.rpthresh end,	
					},
					rpthreshgt = {
						order = 33,
						type = "color",
						name = L["Above threshold"],
						desc = L["Font color above the required Rabid Power stack value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
					rpthreshlt = {
						order = 34,
						type = "color",
						name = L["Below threshold"],
						desc = L["Font color below the required Rabid Power stack value"],
						hasAlpha = false,
						set = function(info,v,v2,v3,v4)
							local var = info[#info]
							local t = dbp[var]
							t[1],t[2],t[3],t[4] = v,v2,v3,v4
						end,
						get = function(info) 
							local var = info[#info]
							return unpack(dbp[var]) 
						end,
					},
				},
			},
		},
	}
	
	options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(MosphetCookies.db)
	options.args.profile.order = 10
end

function module:SetupInterface()
	local mc = CreateFrame("Frame")
	mc.name = "MosphetCookies"
	local mcTitle = mc:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	mcTitle:SetPoint("TOPLEFT", 16, -16)
	mcTitle:SetText("Mosphet Cookies")
	local mcDesc = mc:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	mcDesc:SetPoint("TOPLEFT", 16, -52)
	mcDesc:SetText(L["To access the MosphetCookies options, use the button below or one of the following commands: /mc or /cookies"])
	mcDesc:SetJustifyH("LEFT")
	local button = CreateFrame("Button", nil, mc, "OptionsButtonTemplate")
	button:SetPoint("TOPLEFT", 16, -82)
	button:SetText("Open Config")
	button:SetScript("OnClick", function (this)
		InterfaceOptionsFrameCancel_OnClick()
		HideUIPanel(GameMenuFrame)
		module:ToggleConfig()
	end)
	InterfaceOptions_AddCategory(mc)
end

function module:ToggleConfig() ACD[ACD.OpenFrames.MosphetCookies and "Close" or "Open"](ACD,"MosphetCookies") end

function module:OnInitialize()
	dbp = MosphetCookies.db.profile
	self:RegisterOptions()
	self:SetupInterface()
	
	AC:RegisterOptionsTable("MosphetCookies", options)
	ACD:SetDefaultSize("MosphetCookies", 400, 500)
	
	LibStub("LibAboutPanel").new("MosphetCookies", "MosphetCookies")	
end